==> members-facade-1.0.2-20190531.083519-111-sources.jar: com/bizvane/members/facade/service/qywxapi/CompanyIntegralApiService.java <==
package com.bizvane.members.facade.service.qywxapi;

import com.bizvane.members.facade.models.bo.CompanyExchangeIntegralBo;
import com.bizvane.members.facade.vo.qywx.IntegralExchangeRequestVo;
import com.bizvane.utils.responseinfo.ResponseData;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.Valid;

@FeignClient(value = "${feign.client.members.name}", path = "${feign.client.members.path}")
public interface CompanyIntegralApiService {

    /**
     * 查询crm积分与有赞积分兑换关系
     *
     * @return
     */
    @RequestMapping(value = "/api/companyIntegral/queryYouZanExchangeIntegral", method = RequestMethod.POST)
    ResponseData<CompanyExchangeIntegralBo> queryYouZanExchangeIntegral(@RequestParam(value = "sysCompanyId") Long sysCompanyId, @RequestParam(value = "brandId") Long brandId);
    
    /**
     * 积分兑换
     * @param integralExchangeRequestVo
     * @return
     */
    @RequestMapping(value = "/api/companyIntegral/convertYouZanExchangeIntegral", method = RequestMethod.POST)
    ResponseData<String> convertYouZanExchangeIntegral(@RequestBody @Valid IntegralExchangeRequestVo integralExchangeRequestVo);

    /**
     * 查会员积分
     * @param memberCode
     * @return
     */
    @RequestMapping(value = "/api/companyIntegral/queryMemberIntegral",method = RequestMethod.POST)
    ResponseData<Integer> queryMemberIntegral(@RequestParam(value = "memberCode")String memberCode);

}

==> members-facade-20250718-20250716.022355-1-sources.jar: com/bizvane/members/facade/service/qywxapi/CompanyIntegralApiService.java <==
package com.bizvane.members.facade.service.qywxapi;

import com.bizvane.members.facade.models.bo.CompanyExchangeIntegralBo;
import com.bizvane.members.facade.vo.qywx.IntegralExchangeRequestVo;
import com.bizvane.members.facade.vo.qywx.JudgeYZMemberRequestVo;
import com.bizvane.utils.responseinfo.ResponseData;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.Valid;

@FeignClient(value = "${feign.client.members.name}", path = "${feign.client.members.path}")
public interface CompanyIntegralApiService {

    /**
     * 查询crm积分与有赞积分兑换关系
     *
     * @return
     */
    @RequestMapping(value = "/api/companyIntegral/queryYouZanExchangeIntegral", method = RequestMethod.POST)
    ResponseData<CompanyExchangeIntegralBo> queryYouZanExchangeIntegral(@RequestParam(value = "sysCompanyId") Long sysCompanyId, @RequestParam(value = "brandId") Long brandId);

    /**
     * 积分兑换
     *
     * @param integralExchangeRequestVo
     * @return
     */
    @RequestMapping(value = "/api/companyIntegral/convertYouZanExchangeIntegral", method = RequestMethod.POST)
    ResponseData<String> convertYouZanExchangeIntegral(@RequestBody @Valid IntegralExchangeRequestVo integralExchangeRequestVo);

    /**
     * 查会员积分
     *
     * @param memberCode
     * @return
     */
    @RequestMapping(value = "/api/companyIntegral/queryMemberIntegral", method = RequestMethod.POST)
    ResponseData<Integer> queryMemberIntegral(@RequestParam(value = "memberCode") String memberCode);


    /**
     * 判断是否有赞会员
     *
     * @param judgeYZMemberRequestVo
     * @return
     */
    @RequestMapping(value = "/api/companyIntegral/judegYZMember", method = RequestMethod.POST)
    ResponseData<String> judegYZMember(@RequestBody @Valid JudgeYZMemberRequestVo judgeYZMemberRequestVo);

}
